@@ -1,7 +1,8 @@
 from os import getenv, path
 
-from notfound import extension as not_found
+import sphinx_collapse
 import sphinx_copybutton
+from notfound import extension as not_found
 from sphinx_tabs import tabs
 
 from sphinx_scylladb_theme._version import version
@@ -38,9 +39,15 @@ def compute_hide_toc(context):
 
 
 def update_context(app, pagename, templatename, context, doctree):
+    file_meta = context.get("meta", None) or {}
     context["scylladb_theme_version"] = version
     context["navigation_tree"] = compute_toc_tree
+    context["full_width"] = "full-width" in file_meta
     context["hide_toc"] = compute_hide_toc(context)
+    context["hide_pre_content"] = "hide-pre-content" in file_meta
+    context["hide_post_content"] = "hide-post-content" in file_meta
+    context["hide_version_warning"] = "hide-version-warning" in file_meta
+    context["landing"] = "landing" in file_meta
 
     if (
         hasattr(app.config, "smv_rename_latest_version")
@@ -87,17 +94,20 @@ def setup(app):
     app.add_lexer("cql", CQLLexer())
     app.add_lexer("ditaa", DitaaLexer())
 
+    """Setup thid-party extensions"""
+    not_found.setup(app)
+    sphinx_collapse.setup(app)
+    sphinx_copybutton.setup(app)
+    tabs.setup(app)
+
     """Setup custom extensions"""
     hero_box.setup(app)
     multiversion.setup(app)
-    not_found.setup(app)
     panel_box.setup(app)
     redirects.setup(app)
-    sphinx_copybutton.setup(app)
     from .extensions import substitutions
 
     substitutions.setup(app)
-    tabs.setup(app)
     topic_box.setup(app)
 
     return {"version": version, "parallel_read_safe": True}
